dojo.provide("com.ibm.pb.logging.FirebugLogger");

if(window.console && window.console.firebug && window.ibmConfig && ibmConfig.useFirebugLogger) {
	var lvl = com.ibm.mashups.enabler.logging.LogLevel;
	
	var fbgLogger = dojo.declare("com.ibm.pb.logging.FirebugLogger", null, {
		methods: {},
		constructor: function(name, parent) {
			this.name = name;
			this.parent = parent;
			this._loggers = {};
			this._initConfig(ibmConfig && ibmConfig.traceConfig);
		},
		_initConfig: function(config) {
			if(config && config.length > 0) {
				this._test = new RegExp(dojo.isArray(config) ? config.join("|") : config);
			}
			else {this._test = null;}
		},
		_getTest: function() {
			if(!this._test && this.parent) {return this.parent._getTest();}
			return this._test;
		},
		getLogger: function(loggerName) {
			if(this.parent) {return this.parent.getLogger(loggerName);}
			if(!this._loggers[loggerName]) {
				this._loggers[loggerName] = new this.constructor(loggerName, this);
			}
			return this._loggers[loggerName];
		},
		addHandler: function(handler) {
			// no-op, unsupported
		},
		removeHandler: function(handler) {
			// no-op, unsupported
		},
		entering: function(methodName, args) {
			var trc = lvl.TRACE;
			if(this.isLoggable(trc)) {
				this.log(trc, methodName, "ENTRY ${0}", [args]);
			}
		},
		exiting: function(methodName, args) {
			var trc = lvl.TRACE;
			if(this.isLoggable(trc)) {
				this.log(trc, methodName, "RETURN ${0}", [args]);
			}
		},
		info: function(methodName, message, args) {
			this.log(lvl.INFO, methodName, message, args);
		},	
		warning: function(methodName, message, args) {
			this.log(lvl.WARNING, methodName, message, args);
		},	
		severe: function(methodName, message, args) {
			this.log(lvl.SEVERE, methodName, message, args);
		},
		trace: function(methodName, message, args) {
			this.log(lvl.TRACE, methodName, message, args);
		},
		log: function(logLevel, methodName, message, args) {
			if(this.isLoggable(logLevel)) {
				var msg = this._firebugStyle(this.name + " " + methodName + " - " + message, args);
				console[this.methods[this._normalizeLevel(logLevel)]].apply(window, msg);
			}
		},
		_firebugStyle: function(text, args) {
			var argsArr = [], msg = dojo.string.substitute(text, args, function(value, key){
				argsArr.push(value);
				return dojo.isString(value) ? "%s" : "%o";
			});
			argsArr.unshift(msg);
			return argsArr;
		},
		_normalizeLevel: function(level) {
			var logLvl = lvl.SEVERE;
			if(level <= lvl.SEVERE) {logLvl = lvl.SEVERE;}
			if(level <= lvl.WARNING) {logLvl = lvl.WARNING;}
			if(level <= lvl.INFO) {logLvl = lvl.INFO;}
			if(level <= lvl.TRACE) {logLvl = lvl.TRACE;}
			return logLvl;
		},
		isLoggable: function(logLevel) {
			if(logLevel > lvl.TRACE) {return true;	}
			if(!(ibmConfig && ibmConfig.isDebug)) {return false;}
			var test = this._getTest();
			return test && test.test(this.name);
		}
	});
	
	var methods = fbgLogger.prototype.methods;
	methods[lvl.INFO] = "info";
	methods[lvl.WARNING] = "warn";
	methods[lvl.SEVERE] = "error";
	methods[lvl.TRACE] = "debug";
	
	var baseFbgLogger = com.ibm.mashups.enabler.logging.Logger = new com.ibm.pb.logging.FirebugLogger();
	
	ibmConfig.extensions.push( { 
	    "com.ibm.mashups.enabler.logging.Logger.getLogger": { 
	        type: "around", 
	        handler: function (func, args) { 
	            return baseFbgLogger.getLogger.apply(baseFbgLogger, args);
	        } 
	    } 
	});
}