/* Copyright IBM Corp. 2013  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.iwidget.io");

//<INTERFACE>
/**
 * This interface defines support the iContext is supplying regarding IO operations.<p/>
 *  &nbsp;&nbsp;&nbsp; <code>this.iContext.io.rewriteURI(aUri);</code><p/>
 *
 * @ibm-api
 * @ibm-module iWidget2
 */
dojo.declare("com.ibm.mashups.iwidget.io", null, {
    /**
     * @private
     */
    constructor: function() {
    
    },
    /**
     This object wraps the native XMLHttpRequest support to provide a consistent page in the face of asynchronous updates, especially those which may cause server-side coordination between the server-side components related to multiple iWidgets on the page.
     @type XMLHttpRequest
     @returns{XMLHttpRequest} returns  native XMLHttpRequest object.
     */
    XMLHttpRequest: function() {
    },
    
    /**
     This method takes a URI as a parameter and returns a URI which the browser can resolve for accessing the supplied URI.
     Examples of usage include resolving a relative URI against the source of the iWidget's definition and resolving other URIs to address any intermediate
     gateways, such as a proxy server. <p/>
     &nbsp;&nbsp;&nbsp;Sample usage that resolves URI to address a proxy server ,assume url to proxy server is "/mum/proxy".<br/>
     <code>
     &nbsp;&nbsp;&nbsp; var aUri = "http://yourco.com/mytest.js"; <br/>
     &nbsp;&nbsp;&nbsp; var rc = this.iContext.io.rewriteURI(aUri); <br/>
     </code>
     &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;the result will be "/mum/proxy/http/yourco.com/mytest.js"<br/>
     <br/>
     &nbsp;&nbsp;&nbsp;Sample usage that resolves a relative URI against the source of the iWidget's deinfition<br/>
     &nbsp;&nbsp;&nbsp; Assume iwidget is included on a page as follows:<br/>
     <code>
     &nbsp;&nbsp;&nbsp; &lt;span id="yourcoWidget" class="iw-iWidget"&gt;&lt;a class="iw-Definition" href="/mm/widget-catalog/yourcoWidget.xml"&gt;&lt;/a&gt;&lt;/span&gt;<br/><br/>
     &nbsp;&nbsp;&nbsp; var aUri = "mytest.js"; <br/>
     &nbsp;&nbsp;&nbsp; var rc = this.iContext.io.rewriteURI(aUri);  <br/>
     </code>
     &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;the result will be "/mm/widget-catalog/mytest.js" <br/>
     <br/>
     &nbsp;&nbsp;&nbsp;Sample usage that resolves a relative URI against the source of the iWidget's deinfition for an image resource.<br/>
     &nbsp;&nbsp;&nbsp; Assume iwidget is included on a page as follows:<br/>
     <code>
     &nbsp;&nbsp;&nbsp; &lt;span id="yourcoWidget" class="iw-iWidget"&gt;&lt;a class="iw-Definition" href="http://yourco.com/mm/widget-catalog/yourcoWidget.xml"&gt;&lt;/a&gt;&lt;/span&gt;<br/><br/>
     </code>
     &nbsp;&nbsp;&nbsp;the url for the img resource  of following code will be "http://yourco.com/mm/widget-catalog/mytest.gif" <br/>
     <code>
     &nbsp;&nbsp;&nbsp; var aUri = "mytest.gif"; <br/>
     &nbsp;&nbsp;&nbsp; var returnUri = this.iContext.io.rewriteURI(aUri,false);  <br/>
     &nbsp;&nbsp;&nbsp; var img = dojo.byId(id); <br/>
     &nbsp;&nbsp;&nbsp;  img.src = returnUri;<br/>
     </code>
     @param{String} uri URI that needs to be resolved. Must not be <code>null</code>.
     @param{Boolean} isXhr optional,boolean indicating the url is used as xhr. If no value is provided, the default is true.
     @type String
     @returns{String} return a URI which the browser can resolve for accessing the supplied URI. Must not be <code>null</code>.
     */
    rewriteURI: function(/*String*/uri,/*Boolean*/ isXhr) {
        return null;
    },
	/**
     This convenience method creates a new XMLHttpRequest and send the request with all supplied arguments on the XMLHttpRequest. <br/>
     The supported fields within the arguments object include: <br/>
     <code><br/>
     {<br/>
	   &nbsp;&nbsp;&nbsp; "requestVerb": {"get" | "post" | "put" | "delete"}, <br/>
	   &nbsp;&nbsp;&nbsp;"url": {url},<br/>
       &nbsp;&nbsp;&nbsp;"handleAs": {handleAs},<br/>
       &nbsp;&nbsp;&nbsp;"sync": {boolean},<br/>
       &nbsp;&nbsp;&nbsp;"preventCache": {boolean},<br/>
       &nbsp;&nbsp;&nbsp;"content": {content},<br/>
       &nbsp;&nbsp;&nbsp;"headers": {headers},<br/>
       &nbsp;&nbsp;&nbsp;"timeout": {int},<br/>
	   &nbsp;&nbsp;&nbsp;"user": {user},<br/>
       &nbsp;&nbsp;&nbsp;"password": {password},<br/>
       &nbsp;&nbsp;&nbsp;"form": {form},<br/>
       &nbsp;&nbsp;&nbsp;"msgData": {msgData},<br/>
       &nbsp;&nbsp;&nbsp;"load": {load},<br/>
       &nbsp;&nbsp;&nbsp;"error": {error},<br/>
       &nbsp;&nbsp;&nbsp;"handle": {handle}<br/>
	 }<br/>
	 </code><br/>
     @param{Object} args supported properties as listed above.
     @type void
     */
	xhrReq:function(/*Object*/ args){
		return;
	} 

});
//</INTERFACE>
dojo.require("com.ibm.mm.iwidget.icontext.IContextIOImpl");

